@@ -28,10 +28,14 @@ countHist.unmarkedFramePCount <- function(object, plot.freq = TRUE, ...) {
   
     ##summarize detection histories
     if(plot.freq) {
-    
+
+        par(cex = 1.1,
+            cex.axis = 1.1,
+            cex.lab = 1.1)
+        
         ##create histogram
         barplot(table(yVec), ylab = "Frequency", xlab = "Counts of individuals",
-                main = "Distribution of raw counts", cex.lab = 1.2)
+                main = "Distribution of raw counts")
     }
 
     ##raw counts
@@ -102,10 +106,14 @@ countHist.unmarkedFitPCount <- function(object, plot.freq = TRUE, ...) {
   
   ##summarize detection histories
   if(plot.freq) {
-    
+
+      par(cex = 1.1,
+          cex.axis = 1.1,
+          cex.lab = 1.1)
+      
     ##create histogram
     barplot(table(yVec), ylab = "Frequency", xlab = "Counts of individuals",
-         main = "Distribution of raw counts", cex.lab = 1.2)
+            main = "Distribution of raw counts")
   }
 
     ##raw counts
@@ -177,10 +185,14 @@ countHist.unmarkedFrameGPC <- function(object, plot.freq = TRUE, ...) {
   
     ##summarize detection histories
     if(plot.freq) {
-    
+
+        par(cex = 1.1,
+            cex.axis = 1.1,
+            cex.lab = 1.1)
+        
         ##create histogram
         barplot(table(yVec), ylab = "Frequency", xlab = "Counts of individuals",
-                main = "Distribution of raw counts", cex.lab = 1.2)
+                main = "Distribution of raw counts")
     }
 
     ##raw counts
@@ -252,10 +264,14 @@ countHist.unmarkedFitGPC <- function(object, plot.freq = TRUE, ...) {
     
     ##summarize detection histories
     if(plot.freq) {
-    
+
+        par(cex = 1.1,
+            cex.axis = 1.1,
+            cex.lab = 1.1)
+        
         ##create histogram
         barplot(table(yVec), ylab = "Frequency", xlab = "Counts of individuals",
-                main = "Distribution of raw counts", cex.lab = 1.2)
+                main = "Distribution of raw counts")
     }
 
     ##raw counts
@@ -326,10 +342,14 @@ countHist.unmarkedFrameMPois <- function(object, plot.freq = TRUE, ...) {
     
     ##summarize detection histories
     if(plot.freq) {
-    
+
+        par(cex = 1.1,
+            cex.axis = 1.1,
+            cex.lab = 1.1)
+        
         ##create histogram
         barplot(table(yVec), ylab = "Frequency", xlab = "Counts of individuals",
-                main = "Distribution of raw counts", cex.lab = 1.2)
+                main = "Distribution of raw counts")
     }
 
     ##raw counts
@@ -400,10 +420,14 @@ countHist.unmarkedFitMPois <- function(object, plot.freq = TRUE, ...) {
     
     ##summarize detection histories
     if(plot.freq) {
-    
+
+        par(cex = 1.1,
+            cex.axis = 1.1,
+            cex.lab = 1.1)
+        
         ##create histogram
         barplot(table(yVec), ylab = "Frequency", xlab = "Counts of individuals",
-                main = "Distribution of raw counts", cex.lab = 1.2)
+                main = "Distribution of raw counts")
     }
     
     ##raw counts
@@ -492,35 +516,50 @@ countHist.unmarkedFramePCO <- function(object, plot.freq = TRUE, plot.seasons =
             ##if 2 <- 2 x 1
     
             if(n.seasons.adj >= 10) {
-                par(mfrow = c(4, 3))
+                nRows <- 4
+                nCols <- 3
             } else {
 
                 if(n.seasons.adj >= 7) {
-                    par(mfrow = c(3, 3))
+                    nRows <- 3
+                    nCols <- 3
                 } else {
 
                     if(n.seasons.adj >= 5) {
-                        par(mfrow = c(3, 2))
+                        nRows <- 3
+                        nCols <- 2
                     } else {
                         if(n.seasons.adj == 4) {
-                            par(mfrow = c(2, 2))
+                            nRows <- 2
+                            nCols <- 2
                         } else {
                             if(n.seasons.adj == 3) {
-                                par(mfrow = c(3, 1))
+                                nRows <- 3
+                                nCols <- 1
                             } else {
-                                par(mfrow = c(2, 1))
+                                nRows <- 2
+                                nCols <- 1
                             }
                         }
                     }
                 }
             }
         }
+        par(mfrow = c(nRows, nCols),
+            cex = 1.1,
+            cex.axis = 1.1,
+            cex.lab = 1.1)
     }
 
 
     ##if both plots for seasons and combined are requested
     ##summarize detection histories
     if(plot.freq) {
+
+        if(!plot.seasons) {
+            nRows <- 1
+            nCols <- 1
+        }
         
         if(plot.seasons && n.seasons > 12) {
             n.seasons.adj <- 11
@@ -530,32 +569,41 @@ countHist.unmarkedFramePCO <- function(object, plot.freq = TRUE, plot.seasons =
         if(plot.seasons && n.seasons.adj <= 11) {
             
             if(n.seasons.adj >= 9) {
-                par(mfrow = c(4, 3))
+                nRows <- 4
+                nCols <- 3
             } else {
                 
                 if(n.seasons.adj >= 6) {
-                    par(mfrow = c(3, 3))
+                    nRows <- 3
+                    nCols <- 3
                 } else {
                     
                     if(n.seasons.adj >= 4) {
-                        par(mfrow = c(3, 2))
+                        nRows <- 3
+                        nCols <- 2
                     } else {
                         if(n.seasons.adj == 3) {
-                            par(mfrow = c(2, 2))
+                            nRows <- 2
+                            nCols <- 2
                         } else {
                             if(n.seasons.adj == 2) {
-                                par(mfrow = c(3, 1))
+                                nRows <- 3
+                                nCols <- 1
                             }
                         }
                     }
                 }
             }
         }
-    
+
+        par(mfrow = c(nRows, nCols),
+            cex = 1.1,
+            cex.axis = 1.1,
+            cex.lab = 1.1)
+        
         ##histogram for data combined across seasons
         barplot(table(yVec.full), ylab = "Frequency", xlab = "Counts of individuals",
-                main = paste("Distribution of raw counts (", n.seasons, " seasons combined)", sep = ""),
-                cex.lab = 1.2)
+                main = paste("Distribution of raw counts (", n.seasons, " seasons combined)", sep = ""))
     }
 
     ##raw counts
@@ -620,8 +668,7 @@ countHist.unmarkedFramePCO <- function(object, plot.freq = TRUE, plot.seasons =
     for(k in 1:n.seasons.adj) {
        ##histogram for data combined across seasons
       barplot(table(yVectors[[k]]), ylab = "Frequency", xlab = "Counts of individuals",
-           main = paste("Distribution of raw counts (season ", k, ")", sep = ""),
-           cex.lab = 1.2)
+              main = paste("Distribution of raw counts (season ", k, ")", sep = ""))
     }
   }
   
@@ -692,38 +739,48 @@ countHist.unmarkedFitPCO <- function(object, plot.freq = TRUE, plot.seasons = FA
     
         if(plot.seasons && n.seasons.adj <= 12) {
 
-      ##if n.seasons < 12
-      ##if 12, 11, 10 <- 4 x 3
-      ##if 9, 8, 7 <- 3 x 3
-      ##if 6, 5 <- 3 x 2
-      ##if 4 <- 2 x 2
-      ##if 3 <- 3 x 1
-      ##if 2 <- 2 x 1
+            ##if n.seasons < 12
+            ##if 12, 11, 10 <- 4 x 3
+            ##if 9, 8, 7 <- 3 x 3
+            ##if 6, 5 <- 3 x 2
+            ##if 4 <- 2 x 2
+            ##if 3 <- 3 x 1
+            ##if 2 <- 2 x 1
     
-      if(n.seasons.adj >= 10) {
-        par(mfrow = c(4, 3))
-      } else {
-
-        if(n.seasons.adj >= 7) {
-          par(mfrow = c(3, 3))
-        } else {
-
-          if(n.seasons.adj >= 5) {
-            par(mfrow = c(3, 2))
-          } else {
-            if(n.seasons.adj == 4) {
-              par(mfrow = c(2, 2))
+            if(n.seasons.adj >= 10) {
+                nRows <- 4
+                nCols <- 3
             } else {
-              if(n.seasons.adj == 3) {
-                par(mfrow = c(3, 1))
-              } else {
-                par(mfrow = c(2, 1))
-              }
+                
+                if(n.seasons.adj >= 7) {
+                    nRows <- 3
+                    nCols <- 3
+                } else {
+                    
+                    if(n.seasons.adj >= 5) {
+                        nRows <- 3
+                        nCols <- 2
+                    } else {
+                        if(n.seasons.adj == 4) {
+                            nRows <- 2
+                            nCols <- 2
+                        } else {
+                            if(n.seasons.adj == 3) {
+                                nRows <- 3
+                                nCols <- 1
+                            } else {
+                                nRows <- 2
+                                nCols <- 1
+                            }
+                        }
+                    }
+                }
             }
-          }
         }
-      }
-    }
+        par(mfrow = c(nRows, nCols),
+            cex = 1.1,
+            cex.axis = 1.1,
+            cex.lab = 1.1)
   }
 
 
@@ -731,6 +788,11 @@ countHist.unmarkedFitPCO <- function(object, plot.freq = TRUE, plot.seasons = FA
   ##summarize detection histories
   if(plot.freq) {
 
+      if(!plot.seasons) {
+            nRows <- 1
+            nCols <- 1
+      }
+      
     if(plot.seasons && n.seasons > 12) {
       n.seasons.adj <- 11
       warning("\nOnly first 11 seasons are plotted\n")
@@ -739,36 +801,45 @@ countHist.unmarkedFitPCO <- function(object, plot.freq = TRUE, plot.seasons = FA
     if(plot.seasons && n.seasons.adj <= 11) {
 
       if(n.seasons.adj >= 9) {
-        par(mfrow = c(4, 3))
+          nRows <- 4
+          nCols <- 3
       } else {
 
         if(n.seasons.adj >= 6) {
-          par(mfrow = c(3, 3))
+            nRows <- 3
+            nCols <- 3
         } else {
 
           if(n.seasons.adj >= 4) {
-            par(mfrow = c(3, 2))
+              nRows <- 3
+              nCols <- 2
           } else {
             if(n.seasons.adj == 3) {
-              par(mfrow = c(2, 2))
+                nRows <- 2
+                nCols <- 2
             } else {
               if(n.seasons.adj == 2) {
-                par(mfrow = c(3, 1))
+                  nRows <- 3
+                  nCols <- 1
               }
             }
           }
         }
       }
     }
+
+      par(mfrow = c(nRows, nCols),
+          cex = 1.1,
+          cex.axis = 1.1,
+          cex.lab = 1.1)
     
-    ##histogram for data combined across seasons
-    barplot(table(yVec.full), ylab = "Frequency", xlab = "Counts of individuals",
-         main = paste("Distribution of raw counts (", n.seasons, " seasons combined)", sep = ""),
-         cex.lab = 1.2)
+      ##histogram for data combined across seasons
+      barplot(table(yVec.full), ylab = "Frequency", xlab = "Counts of individuals",
+              main = paste("Distribution of raw counts (", n.seasons, " seasons combined)", sep = ""))
   }
 
-  ##raw counts
-  count.table.full <- table(yVec.full, exclude = NULL, deparse.level = 0)
+    ##raw counts
+    count.table.full <- table(yVec.full, exclude = NULL, deparse.level = 0)
   
   ##summarize count histories
   hist.full <- apply(X = yMat, MARGIN = 1, FUN = function(i) paste(i, collapse = "|"))
@@ -829,8 +900,7 @@ countHist.unmarkedFitPCO <- function(object, plot.freq = TRUE, plot.seasons = FA
     for(k in 1:n.seasons.adj) {
        ##histogram for data combined across seasons
       barplot(table(yVectors[[k]]), ylab = "Frequency", xlab = "Counts of individuals",
-           main = paste("Distribution of raw counts (season ", k, ")", sep = ""),
-           cex.lab = 1.2)
+              main = paste("Distribution of raw counts (season ", k, ")", sep = ""))
     }
   }
   
@@ -910,29 +980,39 @@ countHist.unmarkedFrameGMM <- function(object, plot.freq = TRUE, plot.seasons =
       ##if 2 <- 2 x 1
     
       if(n.seasons.adj >= 10) {
-        par(mfrow = c(4, 3))
+          nRows <- 4
+          nCols <- 3
       } else {
 
         if(n.seasons.adj >= 7) {
-          par(mfrow = c(3, 3))
+            nRows <- 3
+            nCols <- 3
         } else {
 
           if(n.seasons.adj >= 5) {
-            par(mfrow = c(3, 2))
+              nRows <- 3
+              nCols <- 2
           } else {
             if(n.seasons.adj == 4) {
-              par(mfrow = c(2, 2))
+                nRows <- 2
+                nCols <- 2
             } else {
               if(n.seasons.adj == 3) {
-                par(mfrow = c(3, 1))
+                  nRows <- 3
+                  nCols <- 1
               } else {
-                par(mfrow = c(2, 1))
+                  nRows <- 2
+                  nCols <- 1
               }
             }
           }
         }
       }
     }
+      par(mfrow = c(nRows, nCols),
+            cex = 1.1,
+            cex.axis = 1.1,
+            cex.lab = 1.1)
   }
 
 
@@ -940,40 +1020,54 @@ countHist.unmarkedFrameGMM <- function(object, plot.freq = TRUE, plot.seasons =
   ##summarize detection histories
   if(plot.freq) {
 
+      if(!plot.seasons) {
+            nRows <- 1
+            nCols <- 1
+      }
+      
     if(plot.seasons && n.seasons > 12) {
       n.seasons.adj <- 11
       warning("\nOnly first 11 seasons are plotted\n")
     }
 
-    if(plot.seasons && n.seasons.adj <= 11) {
-
-      if(n.seasons.adj >= 9) {
-        par(mfrow = c(4, 3))
-      } else {
-
-        if(n.seasons.adj >= 6) {
-          par(mfrow = c(3, 3))
-        } else {
-
-          if(n.seasons.adj >= 4) {
-            par(mfrow = c(3, 2))
-          } else {
-            if(n.seasons.adj == 3) {
-              par(mfrow = c(2, 2))
+            if(plot.seasons && n.seasons.adj <= 11) {
+            
+            if(n.seasons.adj >= 9) {
+                nRows <- 4
+                nCols <- 3
             } else {
-              if(n.seasons.adj == 2) {
-                par(mfrow = c(3, 1))
-              }
+                
+                if(n.seasons.adj >= 6) {
+                    nRows <- 3
+                    nCols <- 3
+                } else {
+                    
+                    if(n.seasons.adj >= 4) {
+                        nRows <- 3
+                        nCols <- 2
+                    } else {
+                        if(n.seasons.adj == 3) {
+                            nRows <- 2
+                            nCols <- 2
+                        } else {
+                            if(n.seasons.adj == 2) {
+                                nRows <- 3
+                                nCols <- 1
+                            }
+                        }
+                    }
+                }
             }
-          }
         }
-      }
-    }
+
+        par(mfrow = c(nRows, nCols),
+            cex = 1.1,
+            cex.axis = 1.1,
+            cex.lab = 1.1)
     
     ##histogram for data combined across seasons
     barplot(table(yVec.full), ylab = "Frequency", xlab = "Counts of individuals",
-            main = paste("Distribution of raw counts (", n.seasons, " seasons combined)", sep = ""),
-            cex.lab = 1.2)
+            main = paste("Distribution of raw counts (", n.seasons, " seasons combined)", sep = ""))
   }
 
   ##raw counts
@@ -1038,8 +1132,7 @@ countHist.unmarkedFrameGMM <- function(object, plot.freq = TRUE, plot.seasons =
     for(k in 1:n.seasons.adj) {
        ##histogram for data combined across seasons
       barplot(table(yVectors[[k]]), ylab = "Frequency", xlab = "Counts of individuals",
-           main = paste("Distribution of raw counts (season ", k, ")", sep = ""),
-           cex.lab = 1.2)
+              main = paste("Distribution of raw counts (season ", k, ")", sep = ""))
     }
   }
   
@@ -1110,82 +1203,106 @@ countHist.unmarkedFitGMM <- function(object, plot.freq = TRUE, plot.seasons = FA
     
     if(plot.seasons && n.seasons.adj <= 12) {
 
-      ##if n.seasons < 12
-      ##if 12, 11, 10 <- 4 x 3
-      ##if 9, 8, 7 <- 3 x 3
-      ##if 6, 5 <- 3 x 2
-      ##if 4 <- 2 x 2
-      ##if 3 <- 3 x 1
-      ##if 2 <- 2 x 1
+        ##if n.seasons < 12
+        ##if 12, 11, 10 <- 4 x 3
+        ##if 9, 8, 7 <- 3 x 3
+        ##if 6, 5 <- 3 x 2
+        ##if 4 <- 2 x 2
+        ##if 3 <- 3 x 1
+        ##if 2 <- 2 x 1
     
-      if(n.seasons.adj >= 10) {
-        par(mfrow = c(4, 3))
-      } else {
-
-        if(n.seasons.adj >= 7) {
-          par(mfrow = c(3, 3))
+        if(n.seasons.adj >= 10) {
+            nRows <- 4
+            nCols <- 3
         } else {
 
-          if(n.seasons.adj >= 5) {
-            par(mfrow = c(3, 2))
-          } else {
-            if(n.seasons.adj == 4) {
-              par(mfrow = c(2, 2))
+            if(n.seasons.adj >= 7) {
+                nRows <- 3
+                nCols <- 3
             } else {
-              if(n.seasons.adj == 3) {
-                par(mfrow = c(3, 1))
-              } else {
-                par(mfrow = c(2, 1))
-              }
+
+                if(n.seasons.adj >= 5) {
+                    nRows <- 3
+                    nCols <- 2
+                } else {
+                    if(n.seasons.adj == 4) {
+                        nRows <- 2
+                        nCols <- 2
+                    } else {
+                        if(n.seasons.adj == 3) {
+                            nRows <- 3
+                            nCols <- 1
+                        } else {
+                            nRows <- 2
+                            nCols <- 1
+                        }
+                    }
+                }
             }
-          }
         }
-      }
     }
+      par(mfrow = c(nRows, nCols),
+          cex = 1.1,
+          cex.axis = 1.1,
+          cex.lab = 1.1)
   }
 
-
-  ##if both plots for seasons and combined are requested
-  ##summarize detection histories
-  if(plot.freq) {
-
-    if(plot.seasons && n.seasons > 12) {
-      n.seasons.adj <- 11
-      warning("\nOnly first 11 seasons are plotted\n")
-    }
-
-    if(plot.seasons && n.seasons.adj <= 11) {
-
-      if(n.seasons.adj >= 9) {
-        par(mfrow = c(4, 3))
-      } else {
-
-        if(n.seasons.adj >= 6) {
-          par(mfrow = c(3, 3))
-        } else {
-
-          if(n.seasons.adj >= 4) {
-            par(mfrow = c(3, 2))
-          } else {
-            if(n.seasons.adj == 3) {
-              par(mfrow = c(2, 2))
-            } else {
-              if(n.seasons.adj == 2) {
-                par(mfrow = c(3, 1))
-              }
-            }
-          }
-        }
-      }
-    }
     
-    ##histogram for data combined across seasons
-    barplot(table(yVec.full), ylab = "Frequency", xlab = "Counts of individuals",
-         main = paste("Distribution of raw counts (", n.seasons, " seasons combined)", sep = ""),
-         cex.lab = 1.2)
-  }
+    ##if both plots for seasons and combined are requested
+    ##summarize detection histories
+    if(plot.freq) {
 
-  ##raw counts
+        if(!plot.seasons) {
+            nRows <- 1
+            nCols <- 1
+        }
+        
+        if(plot.seasons && n.seasons > 12) {
+            n.seasons.adj <- 11
+            warning("\nOnly first 11 seasons are plotted\n")
+        }
+
+        if(plot.seasons && n.seasons.adj <= 11) {
+            
+            if(n.seasons.adj >= 9) {
+                nRows <- 4
+                nCols <- 3
+            } else {
+                
+                if(n.seasons.adj >= 6) {
+                    nRows <- 3
+                    nCols <- 3
+                } else {
+                    
+                    if(n.seasons.adj >= 4) {
+                        nRows <- 3
+                        nCols <- 2
+                    } else {
+                        if(n.seasons.adj == 3) {
+                            nRows <- 2
+                            nCols <- 2
+                        } else {
+                            if(n.seasons.adj == 2) {
+                                nRows <- 3
+                                nCols <- 1
+                            }
+                        }
+                    }
+                }
+            }
+        }
+        
+        par(mfrow = c(nRows, nCols),
+            cex = 1.1,
+            cex.axis = 1.1,
+            cex.lab = 1.1)
+        
+        ##histogram for data combined across seasons
+        barplot(table(yVec.full), ylab = "Frequency", xlab = "Counts of individuals",
+                main = paste("Distribution of raw counts (", n.seasons, " seasons combined)", sep = ""))
+    }
+
+    ##raw counts
   count.table.full <- table(yVec.full, exclude = NULL, deparse.level = 0)
   
   ##summarize count histories
@@ -1246,9 +1363,472 @@ countHist.unmarkedFitGMM <- function(object, plot.freq = TRUE, plot.seasons = FA
   if(plot.seasons) {
     for(k in 1:n.seasons.adj) {
        ##histogram for data combined across seasons
-      barplot(table(yVectors[[k]]), ylab = "Frequency", xlab = "Counts of individuals",
-           main = paste("Distribution of raw counts (season ", k, ")", sep = ""),
-           cex.lab = 1.2)
+        barplot(table(yVectors[[k]]), ylab = "Frequency", xlab = "Counts of individuals",
+                main = paste("Distribution of raw counts (season ", k, ")", sep = ""))
+    }
+  }
+  
+  ##populate out.freqs with freqs of extinctions and colonizations
+  for(j in 2:n.seasons) {
+    none1 <- out.seasons[[j-1]]$none
+    some1 <- out.seasons[[j-1]]$some
+    none2 <- out.seasons[[j]]$none
+    some2 <- out.seasons[[j]]$some
+    ##colonizations
+    out.freqs[j, 3] <- sum(duplicated(c(some2, none1)))
+    ##extinctions
+    out.freqs[j, 4] <- sum(duplicated(c(some1, none2)))
+    ##no change
+    out.freqs[j, 5] <- sum(duplicated(c(some1, some2))) + sum(duplicated(c(none1, none2)))
+    ##sites both sampled in t and t-1
+    year1 <- c(none1, some1)
+    year2 <- c(none2, some2)
+    out.freqs[j, 6] <- sum(duplicated(c(year1, year2)))
+  }
+
+  ##create a matrix with proportion of sites with colonizations
+  ##and extinctions based on raw data
+  out.props <- matrix(NA, nrow = nrow(out.freqs), ncol = 4)
+  colnames(out.props) <- c("naive.occ", "naive.colonization", "naive.extinction", "naive.static")
+  rownames(out.props) <- rownames(out.freqs)
+  out.props[, 1] <- out.freqs[, 2]/out.freqs[, 1]
+  out.props[, 2] <- out.freqs[, 3]/out.freqs[, 6]
+  out.props[, 3] <- out.freqs[, 4]/out.freqs[, 6]
+  out.props[, 4] <- out.freqs[, 5]/out.freqs[, 6]
+  
+  out.count <- list("count.table.full" = count.table.full,
+                    "count.table.seasons" = count.table.seasons,
+                    "hist.table.full" = hist.table.full,
+                    "hist.table.seasons" = hist.table.seasons,
+                    "out.freqs" = out.freqs, "out.props" = out.props,
+                    "n.seasons" = n.seasons,
+                    "n.visits.season" = n.visits.season)
+  class(out.count) <- "countHist"
+  return(out.count)
+}
+
+
+
+##multmixOpen
+countHist.unmarkedFrameMMO <- function(object, plot.freq = TRUE, plot.seasons = FALSE, ...) {
+
+    ##extract data
+    yMat <- object@y
+    nsites <- nrow(yMat)
+    n.seasons <- object@numPrimary
+    n.seasons.adj <- n.seasons #total number of plots fixed to 11 or 12, depending on plots requested
+    nvisits <- ncol(yMat)
+    ##visits per season
+    n.visits.season <- nvisits/n.seasons
+    seasonNames <- paste("season", 1:n.seasons, sep = "")
+    
+    ##collapse yMat into a single vector
+    yVec.full <- as.vector(yMat)
+  
+    ##if only season-specific plots are requested
+    if(!plot.freq && plot.seasons) {
+        ##determine arrangement of plots in matrix
+        if(plot.seasons && n.seasons > 12) {
+            n.seasons.adj <- 12
+            warning("\nOnly first 12 seasons are plotted\n")
+        }
+        
+        if(plot.seasons && n.seasons.adj <= 12) {
+
+            ##if n.seasons < 12
+            ##if 12, 11, 10 <- 4 x 3
+            ##if 9, 8, 7 <- 3 x 3
+            ##if 6, 5 <- 3 x 2
+            ##if 4 <- 2 x 2
+            ##if 3 <- 3 x 1
+            ##if 2 <- 2 x 1
+    
+            if(n.seasons.adj >= 10) {
+                nRows <- 4
+                nCols <- 3
+            } else {
+
+                if(n.seasons.adj >= 7) {
+                    nRows <- 3
+                    nCols <- 3
+                } else {
+
+                    if(n.seasons.adj >= 5) {
+                        nRows <- 3
+                        nCols <- 2
+                    } else {
+                        if(n.seasons.adj == 4) {
+                            nRows <- 2
+                            nCols <- 2
+                        } else {
+                            if(n.seasons.adj == 3) {
+                                nRows <- 3
+                                nCols <- 1
+                            } else {
+                                nRows <- 2
+                                nCols <- 1
+                            }
+                        }
+                    }
+                }
+            }
+        }
+        par(mfrow = c(nRows, nCols),
+            cex = 1.1,
+            cex.axis = 1.1,
+            cex.lab = 1.1)
+    }
+    
+
+    ##if both plots for seasons and combined are requested
+    ##summarize detection histories
+    if(plot.freq) {
+
+        if(!plot.seasons) {
+            nRows <- 1
+            nCols <- 1
+        }
+        
+        if(plot.seasons && n.seasons > 12) {
+            n.seasons.adj <- 11
+            warning("\nOnly first 11 seasons are plotted\n")
+        }
+
+        if(plot.seasons && n.seasons.adj <= 11) {
+            
+            if(n.seasons.adj >= 9) {
+                nRows <- 4
+                nCols <- 3
+            } else {
+                
+                if(n.seasons.adj >= 6) {
+                    nRows <- 3
+                    nCols <- 3
+                } else {
+                    
+                    if(n.seasons.adj >= 4) {
+                        nRows <- 3
+                        nCols <- 2
+                    } else {
+                        if(n.seasons.adj == 3) {
+                            nRows <- 2
+                            nCols <- 2
+                        } else {
+                            if(n.seasons.adj == 2) {
+                                nRows <- 3
+                                nCols <- 1
+                            }
+                        }
+                    }
+                }
+            }
+        }
+
+        par(mfrow = c(nRows, nCols),
+            cex = 1.1,
+            cex.axis = 1.1,
+            cex.lab = 1.1)
+
+        ##histogram for data combined across seasons
+        barplot(table(yVec.full), ylab = "Frequency", xlab = "Counts of individuals",
+                main = paste("Distribution of raw counts (", n.seasons, " seasons combined)", sep = ""))
+    }
+
+    ##raw counts
+    count.table.full <- table(yVec.full, exclude = NULL, deparse.level = 0)
+  
+    ##summarize count histories
+    hist.full <- apply(X = yMat, MARGIN = 1, FUN = function(i) paste(i, collapse = "|"))
+    hist.table.full <- table(hist.full, deparse.level = 0)
+
+    ##for each season, determine frequencies
+    yVectors <- vector(mode = "list", length = n.seasons)
+    out.seasons <- vector(mode = "list", length = n.seasons)
+    count.table.seasons <- vector(mode = "list", length = n.seasons)
+    names(count.table.seasons) <- seasonNames
+
+    hist.table.seasons <- vector(mode = "list", length = n.seasons)
+    names(hist.table.seasons) <- seasonNames
+    
+    out.freqs <- matrix(data = NA, ncol = 6, nrow = n.seasons)
+    colnames(out.freqs) <- c("sampled", "detected", "colonized",
+                             "extinct", "static", "common")
+    rownames(out.freqs) <- paste("Season-", 1:n.seasons, sep = "")
+
+    ##sequence of visits
+    vis.seq <- seq(from = 1, to = nvisits, by = n.visits.season)
+    for(i in 1:n.seasons) {
+        col.start <- vis.seq[i]
+        col.end <- col.start + (n.visits.season - 1)
+        ySeason <- yMat[, col.start:col.end]
+        ##summarize count histories
+        if(is.null(ncol(ySeason))){
+            ySeason <- as.matrix(ySeason)
+        }
+        yVec.season <- as.vector(ySeason)
+        yVectors[[i]] <- yVec.season
+        
+        det.hist <- apply(X = ySeason, MARGIN = 1, FUN = function(i) paste(i, collapse = "|"))
+        hist.table.seasons[[i]] <- table(det.hist, deparse.level = 0)
+        count.table.seasons[[i]] <- table(yVec.season, exclude = NULL)
+
+        ##determine proportion of sites with at least 1 detection
+        det.sum <- apply(X = ySeason, MARGIN = 1, FUN = function(i) ifelse(sum(i, na.rm = TRUE) > 0, 1, 0))
+
+        ##check sites with observed detections and deal with NA's
+        sum.rows <- rowSums(ySeason, na.rm = TRUE)
+        is.na(sum.rows) <- rowSums(is.na(ySeason)) == ncol(ySeason)
+    
+        ##number of sites sampled
+        out.freqs[i, 1] <- sum(!is.na(sum.rows))
+        out.freqs[i, 2] <- sum(det.sum)
+
+
+    #sites without detections
+    none <- which(sum.rows == 0)
+    #sites with at least one detection
+    some <- which(sum.rows != 0) 
+    out.seasons[[i]] <- list("none" = none, "some" = some)
+  }
+
+  ##iterate over each season
+  if(plot.seasons) {
+    for(k in 1:n.seasons.adj) {
+       ##histogram for data combined across seasons
+        barplot(table(yVectors[[k]]), ylab = "Frequency", xlab = "Counts of individuals",
+                main = paste("Distribution of raw counts (season ", k, ")", sep = ""))
+    }
+  }
+  
+  ##populate out.freqs with freqs of extinctions and colonizations
+  for(j in 2:n.seasons) {
+    none1 <- out.seasons[[j-1]]$none
+    some1 <- out.seasons[[j-1]]$some
+    none2 <- out.seasons[[j]]$none
+    some2 <- out.seasons[[j]]$some
+    ##colonizations
+    out.freqs[j, 3] <- sum(duplicated(c(some2, none1)))
+    ##extinctions
+    out.freqs[j, 4] <- sum(duplicated(c(some1, none2)))
+    ##no change
+    out.freqs[j, 5] <- sum(duplicated(c(some1, some2))) + sum(duplicated(c(none1, none2)))
+    ##sites both sampled in t and t-1
+    year1 <- c(none1, some1)
+    year2 <- c(none2, some2)
+    out.freqs[j, 6] <- sum(duplicated(c(year1, year2)))
+  }
+
+  ##create a matrix with proportion of sites with colonizations
+  ##and extinctions based on raw data
+  out.props <- matrix(NA, nrow = nrow(out.freqs), ncol = 4)
+  colnames(out.props) <- c("naive.occ", "naive.colonization", "naive.extinction", "naive.static")
+  rownames(out.props) <- rownames(out.freqs)
+  out.props[, 1] <- out.freqs[, 2]/out.freqs[, 1]
+  out.props[, 2] <- out.freqs[, 3]/out.freqs[, 6]
+  out.props[, 3] <- out.freqs[, 4]/out.freqs[, 6]
+  out.props[, 4] <- out.freqs[, 5]/out.freqs[, 6]
+  
+  out.count <- list("count.table.full" = count.table.full,
+                    "count.table.seasons" = count.table.seasons,
+                    "hist.table.full" = hist.table.full,
+                    "hist.table.seasons" = hist.table.seasons,
+                    "out.freqs" = out.freqs, "out.props" = out.props,
+                    "n.seasons" = n.seasons,
+                    "n.visits.season" = n.visits.season)
+  class(out.count) <- "countHist"
+  return(out.count)
+}
+
+
+
+##for unmarkedFitMMO
+countHist.unmarkedFitMMO <- function(object, plot.freq = TRUE, plot.seasons = FALSE, ...) {
+
+    ##extract data
+    yMat <- object@data@y
+    nsites <- nrow(yMat)
+    n.seasons <- object@data@numPrimary
+    n.seasons.adj <- n.seasons #total number of plots fixed to 11 or 12, depending on plots requested
+    nvisits <- ncol(yMat)
+    ##visits per season
+    n.visits.season <- nvisits/n.seasons
+    seasonNames <- paste("season", 1:n.seasons, sep = "")
+
+    ##collapse yMat into a single vector
+    yVec.full <- as.vector(yMat)
+  
+    ##if only season-specific plots are requested
+    if(!plot.freq && plot.seasons) {
+        ##determine arrangement of plots in matrix
+        if(plot.seasons && n.seasons > 12) {
+            n.seasons.adj <- 12
+            warning("\nOnly first 12 seasons are plotted\n")
+        }
+    
+        if(plot.seasons && n.seasons.adj <= 12) {
+
+            ##if n.seasons < 12
+            ##if 12, 11, 10 <- 4 x 3
+            ##if 9, 8, 7 <- 3 x 3
+            ##if 6, 5 <- 3 x 2
+            ##if 4 <- 2 x 2
+            ##if 3 <- 3 x 1
+            ##if 2 <- 2 x 1
+    
+            if(n.seasons.adj >= 10) {
+                nRows <- 4
+                nCols <- 3
+            } else {
+
+                if(n.seasons.adj >= 7) {
+                    nRows <- 3
+                    nCols <- 3
+                } else {
+
+                    if(n.seasons.adj >= 5) {
+                        nRows <- 3
+                        nCols <- 2
+                    } else {
+                        if(n.seasons.adj == 4) {
+                            nRows <- 2
+                            nCols <- 2
+                        } else {
+                            if(n.seasons.adj == 3) {
+                                nRows <- 3
+                                nCols <- 1
+                            } else {
+                                nRows <- 2
+                                nCols <- 1
+                            }
+                        }
+                    }
+                }
+            }
+        }
+        par(mfrow = c(nRows, nCols),
+            cex = 1.1,
+            cex.axis = 1.1,
+            cex.lab = 1.1)
+    }
+
+    
+    ##if both plots for seasons and combined are requested
+    ##summarize detection histories
+    if(plot.freq) {
+
+        if(!plot.seasons) {
+            nRows <- 1
+            nCols <- 1
+        }
+                
+        if(plot.seasons && n.seasons > 12) {
+            n.seasons.adj <- 11
+            warning("\nOnly first 11 seasons are plotted\n")
+        }
+
+        if(plot.seasons && n.seasons.adj <= 11) {
+            
+            if(n.seasons.adj >= 9) {
+                nRows <- 4
+                nCols <- 3
+            } else {
+                
+                if(n.seasons.adj >= 6) {
+                    nRows <- 3
+                    nCols <- 3
+                } else {
+                    
+                    if(n.seasons.adj >= 4) {
+                        nRows <- 3
+                        nCols <- 2
+                    } else {
+                        if(n.seasons.adj == 3) {
+                            nRows <- 2
+                            nCols <- 2
+                        } else {
+                            if(n.seasons.adj == 2) {
+                                nRows <- 3
+                                nCols <- 1
+                            }
+                        }
+                    }
+                }
+            }
+        }
+
+        par(mfrow = c(nRows, nCols),
+            cex = 1.1,
+            cex.axis = 1.1,
+            cex.lab = 1.1)
+
+        ##histogram for data combined across seasons
+        barplot(table(yVec.full), ylab = "Frequency", xlab = "Counts of individuals",
+                main = paste("Distribution of raw counts (", n.seasons, " seasons combined)", sep = ""))
+    }
+
+  ##raw counts
+  count.table.full <- table(yVec.full, exclude = NULL, deparse.level = 0)
+  
+  ##summarize count histories
+  hist.full <- apply(X = yMat, MARGIN = 1, FUN = function(i) paste(i, collapse = "|"))
+  hist.table.full <- table(hist.full, deparse.level = 0)
+
+    ##for each season, determine frequencies
+    yVectors <- vector(mode = "list", length = n.seasons)
+    out.seasons <- vector(mode = "list", length = n.seasons)
+    count.table.seasons <- vector(mode = "list", length = n.seasons)
+    names(count.table.seasons) <- seasonNames
+
+    hist.table.seasons <- vector(mode = "list", length = n.seasons)
+    names(hist.table.seasons) <- seasonNames
+    
+    out.freqs <- matrix(data = NA, ncol = 6, nrow = n.seasons)
+    colnames(out.freqs) <- c("sampled", "detected", "colonized",
+                             "extinct", "static", "common")
+    rownames(out.freqs) <- paste("Season-", 1:n.seasons, sep = "")
+
+  ##sequence of visits
+  vis.seq <- seq(from = 1, to = nvisits, by = n.visits.season)
+  for(i in 1:n.seasons) {
+    col.start <- vis.seq[i]
+    col.end <- col.start + (n.visits.season - 1)
+    ySeason <- yMat[, col.start:col.end]
+    ##summarize count histories
+    if(is.null(ncol(ySeason))){
+      ySeason <- as.matrix(ySeason)
+    }
+    yVec.season <- as.vector(ySeason)
+    yVectors[[i]] <- yVec.season
+    
+    det.hist <- apply(X = ySeason, MARGIN = 1, FUN = function(i) paste(i, collapse = "|"))
+    hist.table.seasons[[i]] <- table(det.hist, deparse.level = 0)
+    count.table.seasons[[i]] <- table(yVec.season, exclude = NULL)
+
+    ##determine proportion of sites with at least 1 detection
+    det.sum <- apply(X = ySeason, MARGIN = 1, FUN = function(i) ifelse(sum(i, na.rm = TRUE) > 0, 1, 0))
+
+    ##check sites with observed detections and deal with NA's
+    sum.rows <- rowSums(ySeason, na.rm = TRUE)
+    is.na(sum.rows) <- rowSums(is.na(ySeason)) == ncol(ySeason)
+    
+    ##number of sites sampled
+    out.freqs[i, 1] <- sum(!is.na(sum.rows))
+    out.freqs[i, 2] <- sum(det.sum)
+
+
+    #sites without detections
+    none <- which(sum.rows == 0)
+    #sites with at least one detection
+    some <- which(sum.rows != 0) 
+    out.seasons[[i]] <- list("none" = none, "some" = some)
+  }
+
+  ##iterate over each season
+  if(plot.seasons) {
+    for(k in 1:n.seasons.adj) {
+        ##histogram for data combined across seasons
+        barplot(table(yVectors[[k]]), ylab = "Frequency", xlab = "Counts of individuals",
+                main = paste("Distribution of raw counts (season ", k, ")", sep = ""))
     }
   }
   
