@@ -309,7 +309,18 @@ detHist.unmarkedMultFrame <- function(object, ...) {
     seasonNames <- paste("season", 1:n.seasons, sep = "")
     
     ##summarize detection histories
-    hist.full <- apply(X = yMat, MARGIN = 1, FUN = function(i) paste(i, collapse = "'"))
+    ##starting and ending columns
+    colStarts <- seq(from = 1, to = nvisits, by = n.visits.season)
+    colEnds <- colStarts + (n.visits.season - 1)
+    yrows <- list( )
+
+    ##subsequent seasons
+    for(i in 1:n.seasons) {
+        yrows[[i]] <- apply(yMat[, colStarts[i]:colEnds[i]], MARGIN = 1, FUN = function(i) paste(i, collapse = ""))
+    }
+
+    ##organize and paste rows
+    hist.full <- do.call(what = "paste", args = c(yrows, sep = "'"))
     hist.table.full <- table(hist.full, deparse.level = 0)
     
     ##for each season, determine frequencies
@@ -402,9 +413,20 @@ detHist.unmarkedFitColExt <- function(object, ...) {
     ##visits per season
     n.visits.season <- nvisits/n.seasons
     seasonNames <- paste("season", 1:n.seasons, sep = "")
-    
+
     ##summarize detection histories
-    hist.full <- apply(X = yMat, MARGIN = 1, FUN = function(i) paste(i, collapse = "'"))
+    ##starting and ending columns
+    colStarts <- seq(from = 1, to = nvisits, by = n.visits.season)
+    colEnds <- colStarts + (n.visits.season - 1)
+    yrows <- list( )
+
+    ##subsequent seasons
+    for(i in 1:n.seasons) {
+        yrows[[i]] <- apply(yMat[, colStarts[i]:colEnds[i]], MARGIN = 1, FUN = function(i) paste(i, collapse = ""))
+    }
+
+    ##organize and paste rows
+    hist.full <- do.call(what = "paste", args = c(yrows, sep = "'"))
     hist.table.full <- table(hist.full, deparse.level = 0)
 
     ##for each season, determine frequencies
@@ -669,6 +691,316 @@ detHist.unmarkedFitOccuMulti <- function(object, ...) {
 
 
 
+##for occuMS
+detHist.unmarkedFrameOccuMS <- function(object, ...) {
+
+    ##extract data
+    yMat <- object@y
+    nsites <- nrow(yMat)
+    n.seasons <- object@numPrimary
+    nvisits <- ncol(yMat)
+    ##visits per season
+    n.visits.season <- nvisits/n.seasons
+    seasonNames <- paste("season", 1:n.seasons, sep = "")
+    
+    ##for each season, determine frequencies
+    out.seasons <- vector(mode = "list", length = n.seasons)
+    hist.table.seasons <- vector(mode = "list", length = n.seasons)
+    names(hist.table.seasons) <- seasonNames
+
+    if(n.seasons == 1) {
+        ##summarize detection histories
+        hist.full <- apply(X = yMat, MARGIN = 1, FUN = function(i) paste(i, collapse = ""))
+        hist.table.full <- table(hist.full, deparse.level = 0)
+
+        out.freqs <- matrix(data = NA, ncol = 2, nrow = 1)
+        colnames(out.freqs) <- c("sampled", "detected")
+        rownames(out.freqs) <- "Season-1"
+
+        ##sequence of visits
+        vis.seq <- seq(from = 1, to = nvisits, by = n.visits.season)
+        for(i in 1:n.seasons) {
+            col.start <- vis.seq[i]
+            col.end <- col.start + (n.visits.season - 1)
+            ySeason <- yMat[, col.start:col.end]
+            ##summarize detection histories
+            det.hist <- apply(X = ySeason, MARGIN = 1, FUN = function(i) paste(i, collapse = ""))
+            hist.table.seasons[[i]] <- table(det.hist, deparse.level = 0)
+
+            ##determine proportion of sites with at least 1 detection
+            det.sum <- apply(X = ySeason, MARGIN = 1, FUN = function(i) ifelse(sum(i, na.rm = TRUE) > 0, 1, 0))
+
+            ##check sites with observed detections and deal with NA's
+            sum.rows <- rowSums(ySeason, na.rm = TRUE)
+            is.na(sum.rows) <- rowSums(is.na(ySeason)) == ncol(ySeason)
+        
+            ##number of sites sampled
+            out.freqs[i, 1] <- sum(!is.na(sum.rows))
+            out.freqs[i, 2] <- sum(det.sum)
+
+            ##sites without detections
+            none <- which(sum.rows == 0)
+            ##sites with at least one detection
+            some <- which(sum.rows != 0) 
+            out.seasons[[i]] <- list("none" = none, "some" = some)
+        }
+
+        out.props <- matrix(NA, nrow = 1, ncol = 1)
+        colnames(out.props) <- "naive.occ"
+        rownames(out.props) <- rownames(out.freqs)
+        out.props[, 1] <- out.freqs[, 2]/out.freqs[, 1]
+    }
+
+    if(n.seasons > 1) {
+
+        ##summarize detection histories
+        ##starting and ending columns
+        colStarts <- seq(from = 1, to = nvisits, by = n.visits.season)
+        colEnds <- colStarts + (n.visits.season - 1)
+        yrows <- list( )
+
+        ##subsequent seasons
+        for(i in 1:n.seasons) {
+            yrows[[i]] <- apply(yMat[, colStarts[i]:colEnds[i]], MARGIN = 1, FUN = function(i) paste(i, collapse = ""))
+        }
+
+        ##organize and paste rows
+        hist.full <- do.call(what = "paste", args = c(yrows, sep = "'"))
+        hist.table.full <- table(hist.full, deparse.level = 0)
+
+        
+        out.freqs <- matrix(data = NA, ncol = 6, nrow = n.seasons)
+        colnames(out.freqs) <- c("sampled", "detected", "colonized",
+                                 "extinct", "static", "common")
+        rownames(out.freqs) <- paste("Season-", 1:n.seasons, sep = "")
+
+        ##sequence of visits
+        vis.seq <- seq(from = 1, to = nvisits, by = n.visits.season)
+        
+        for(i in 1:n.seasons) {
+            col.start <- vis.seq[i]
+            col.end <- col.start + (n.visits.season - 1)
+            ySeason <- yMat[, col.start:col.end]
+            ##summarize detection histories
+            det.hist <- apply(X = ySeason, MARGIN = 1, FUN = function(i) paste(i, collapse = ""))
+            hist.table.seasons[[i]] <- table(det.hist, deparse.level = 0)
+
+            ##determine number of sites with at least 1 detection
+            det.sum <- apply(X = ySeason, MARGIN = 1, FUN = function(i) ifelse(sum(i, na.rm = TRUE) > 0, 1, 0))
+
+            ##check sites with observed detections and deal with NA's
+            sum.rows <- rowSums(ySeason, na.rm = TRUE)
+            is.na(sum.rows) <- rowSums(is.na(ySeason)) == ncol(ySeason)
+        
+            ##number of sites sampled
+            out.freqs[i, 1] <- sum(!is.na(sum.rows))
+            out.freqs[i, 2] <- sum(det.sum)
+
+            ##sites without detections
+            none <- which(sum.rows == 0)
+            ##sites with at least one detection
+            some <- which(sum.rows != 0) 
+            out.seasons[[i]] <- list("none" = none, "some" = some)
+        }
+
+        ##populate out.freqs with freqs of extinctions and colonizations
+        for(j in 2:n.seasons) {
+            none1 <- out.seasons[[j-1]]$none
+            some1 <- out.seasons[[j-1]]$some
+            none2 <- out.seasons[[j]]$none
+            some2 <- out.seasons[[j]]$some
+            ##colonizations
+            out.freqs[j, 3] <- sum(duplicated(c(some2, none1)))
+            ##extinctions
+            out.freqs[j, 4] <- sum(duplicated(c(some1, none2)))
+            ##no change
+            out.freqs[j, 5] <- sum(duplicated(c(some1, some2))) + sum(duplicated(c(none1, none2)))
+            ##sites both sampled in t and t-1
+            year1 <- c(none1, some1)
+            year2 <- c(none2, some2)
+            out.freqs[j, 6] <- sum(duplicated(c(year1, year2)))
+        }
+    
+        
+        ##create a matrix with proportion of sites with colonizations
+        ##and extinctions based on raw data
+        out.props <- matrix(NA, nrow = nrow(out.freqs), ncol = 4)
+        colnames(out.props) <- c("naive.occ", "naive.colonization", "naive.extinction", "naive.static")
+        rownames(out.props) <- rownames(out.freqs)
+        out.props[, 1] <- out.freqs[, 2]/out.freqs[, 1]
+        out.props[, 2] <- out.freqs[, 3]/out.freqs[, 6]
+        out.props[, 3] <- out.freqs[, 4]/out.freqs[, 6]
+        out.props[, 4] <- out.freqs[, 5]/out.freqs[, 6]
+    }
+    
+
+    out.det <- list("hist.table.full" = hist.table.full,
+                    "hist.table.seasons" = hist.table.seasons,
+                    "out.freqs" = out.freqs, "out.props" = out.props,
+                    "n.seasons" = n.seasons,
+                    "n.visits.season" = n.visits.season,
+                    "n.species" = 1)
+    class(out.det) <- "detHist"
+    return(out.det)
+}
+
+
+
+##for occuMS
+detHist.unmarkedFitOccuMS <- function(object, ...) {
+
+
+    ##extract data
+    yMat <- object@data@y
+    nsites <- nrow(yMat)
+    n.seasons <- object@data@numPrimary
+    nvisits <- ncol(yMat)
+    ##visits per season
+    n.visits.season <- nvisits/n.seasons
+    seasonNames <- paste("season", 1:n.seasons, sep = "")
+    
+    ##for each season, determine frequencies
+    out.seasons <- vector(mode = "list", length = n.seasons)
+    hist.table.seasons <- vector(mode = "list", length = n.seasons)
+    names(hist.table.seasons) <- seasonNames
+    
+    if(n.seasons == 1) {
+        ##summarize detection histories
+        hist.full <- apply(X = yMat, MARGIN = 1, FUN = function(i) paste(i, collapse = ""))
+        hist.table.full <- table(hist.full, deparse.level = 0)
+
+        out.freqs <- matrix(data = NA, ncol = 2, nrow = 1)
+        colnames(out.freqs) <- c("sampled", "detected")
+        rownames(out.freqs) <- "Season-1"
+
+        ##sequence of visits
+        vis.seq <- seq(from = 1, to = nvisits, by = n.visits.season)
+        for(i in 1:n.seasons) {
+            col.start <- vis.seq[i]
+            col.end <- col.start + (n.visits.season - 1)
+            ySeason <- yMat[, col.start:col.end]
+            ##summarize detection histories
+            det.hist <- apply(X = ySeason, MARGIN = 1, FUN = function(i) paste(i, collapse = ""))
+            hist.table.seasons[[i]] <- table(det.hist, deparse.level = 0)
+
+            ##determine proportion of sites with at least 1 detection
+            det.sum <- apply(X = ySeason, MARGIN = 1, FUN = function(i) ifelse(sum(i, na.rm = TRUE) > 0, 1, 0))
+
+            ##check sites with observed detections and deal with NA's
+            sum.rows <- rowSums(ySeason, na.rm = TRUE)
+            is.na(sum.rows) <- rowSums(is.na(ySeason)) == ncol(ySeason)
+        
+            ##number of sites sampled
+            out.freqs[i, 1] <- sum(!is.na(sum.rows))
+            out.freqs[i, 2] <- sum(det.sum)
+
+            ##sites without detections
+            none <- which(sum.rows == 0)
+            ##sites with at least one detection
+            some <- which(sum.rows != 0) 
+            out.seasons[[i]] <- list("none" = none, "some" = some)
+        }
+
+        out.props <- matrix(NA, nrow = 1, ncol = 1)
+        colnames(out.props) <- "naive.occ"
+        rownames(out.props) <- rownames(out.freqs)
+        out.props[, 1] <- out.freqs[, 2]/out.freqs[, 1]
+    }
+
+    if(n.seasons > 1) {
+
+        ##summarize detection histories
+        ##starting and ending columns
+        colStarts <- seq(from = 1, to = nvisits, by = n.visits.season)
+        colEnds <- colStarts + (n.visits.season - 1)
+        yrows <- list( )
+
+        ##subsequent seasons
+        for(i in 1:n.seasons) {
+            yrows[[i]] <- apply(yMat[, colStarts[i]:colEnds[i]], MARGIN = 1, FUN = function(i) paste(i, collapse = ""))
+        }
+
+        ##organize and paste rows
+        hist.full <- do.call(what = "paste", args = c(yrows, sep = "'"))
+        hist.table.full <- table(hist.full, deparse.level = 0)
+
+        
+        out.freqs <- matrix(data = NA, ncol = 6, nrow = n.seasons)
+        colnames(out.freqs) <- c("sampled", "detected", "colonized",
+                                 "extinct", "static", "common")
+        rownames(out.freqs) <- paste("Season-", 1:n.seasons, sep = "")
+
+        ##sequence of visits
+        vis.seq <- seq(from = 1, to = nvisits, by = n.visits.season)
+        for(i in 1:n.seasons) {
+            col.start <- vis.seq[i]
+            col.end <- col.start + (n.visits.season - 1)
+            ySeason <- yMat[, col.start:col.end]
+            ##summarize detection histories
+            det.hist <- apply(X = ySeason, MARGIN = 1, FUN = function(i) paste(i, collapse = ""))
+            hist.table.seasons[[i]] <- table(det.hist, deparse.level = 0)
+
+            ##determine number of sites with at least 1 detection
+            det.sum <- apply(X = ySeason, MARGIN = 1, FUN = function(i) ifelse(sum(i, na.rm = TRUE) > 0, 1, 0))
+
+            ##check sites with observed detections and deal with NA's
+            sum.rows <- rowSums(ySeason, na.rm = TRUE)
+            is.na(sum.rows) <- rowSums(is.na(ySeason)) == ncol(ySeason)
+        
+            ##number of sites sampled
+            out.freqs[i, 1] <- sum(!is.na(sum.rows))
+            out.freqs[i, 2] <- sum(det.sum)
+
+            ##sites without detections
+            none <- which(sum.rows == 0)
+            ##sites with at least one detection
+            some <- which(sum.rows != 0) 
+            out.seasons[[i]] <- list("none" = none, "some" = some)
+        }
+
+        ##populate out.freqs with freqs of extinctions and colonizations
+        for(j in 2:n.seasons) {
+            none1 <- out.seasons[[j-1]]$none
+            some1 <- out.seasons[[j-1]]$some
+            none2 <- out.seasons[[j]]$none
+            some2 <- out.seasons[[j]]$some
+            ##colonizations
+            out.freqs[j, 3] <- sum(duplicated(c(some2, none1)))
+            ##extinctions
+            out.freqs[j, 4] <- sum(duplicated(c(some1, none2)))
+            ##no change
+            out.freqs[j, 5] <- sum(duplicated(c(some1, some2))) + sum(duplicated(c(none1, none2)))
+            ##sites both sampled in t and t-1
+            year1 <- c(none1, some1)
+            year2 <- c(none2, some2)
+            out.freqs[j, 6] <- sum(duplicated(c(year1, year2)))
+        }
+    
+        
+        ##create a matrix with proportion of sites with colonizations
+        ##and extinctions based on raw data
+        out.props <- matrix(NA, nrow = nrow(out.freqs), ncol = 4)
+        colnames(out.props) <- c("naive.occ", "naive.colonization", "naive.extinction", "naive.static")
+        rownames(out.props) <- rownames(out.freqs)
+        out.props[, 1] <- out.freqs[, 2]/out.freqs[, 1]
+        out.props[, 2] <- out.freqs[, 3]/out.freqs[, 6]
+        out.props[, 3] <- out.freqs[, 4]/out.freqs[, 6]
+        out.props[, 4] <- out.freqs[, 5]/out.freqs[, 6]
+    }
+    
+
+    out.det <- list("hist.table.full" = hist.table.full,
+                    "hist.table.seasons" = hist.table.seasons,
+                    "out.freqs" = out.freqs, "out.props" = out.props,
+                    "n.seasons" = n.seasons,
+                    "n.visits.season" = n.visits.season,
+                    "n.species" = 1)
+    class(out.det) <- "detHist"
+    return(out.det)
+}
+
+
+
 ##print method
 print.detHist <- function(x, digits = 2, ...) {
     ##convert NA to . for nicer printing
